// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef PLAYLIST_H
#define PLAYLIST_H

#include "treeview.h"
#include "app_window.h"

class PlaylistView : public DNDTreeViewBase
{
	public:
		PlaylistView(Playedit::App& app_window);

		void PopulateStore(
				const std::vector< Glib::RefPtr<playlist_t> >& playlist_list,
				MusicView* music_view);
		void ClearTrack(const uint32_t track_id);

		// Global actions used by the UI Managaer
		void SetPlaylistNameEditable();
		void DeletePlaylists();
		void NewPlaylist();
		void RemoveTracksFromPlaylist();

	private:
		void PlaylistNameDataFunc(Gtk::CellRenderer *renderer,
				const Gtk::TreeIter& iter);
		bool SelectionFunc(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreePath& path, bool path_currently_selected);
		void SelectionChanged();
		bool SearchEqualFunc(const Glib::RefPtr<Gtk::TreeModel>& model,
				int column, const Glib::ustring& key, const Gtk::TreeIter& iter);

		// This action can be private
		void RenamePlaylist(const Glib::ustring& string_path, const Glib::ustring& new_name);
		void CancelRenamePlaylist();

		// Drag and drop
		bool on_button_press_event(GdkEventButton* event);
		void on_drag_begin(const Glib::RefPtr<Gdk::DragContext>& context);
		bool on_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context,
				int x, int y, guint time);
		void on_drag_leave(const Glib::RefPtr<Gdk::DragContext>& context, guint time);
		void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
				int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
		void on_drag_end(const Glib::RefPtr<Gdk::DragContext>& context);

		// Timeouts
		bool Expand();
		bool AutoScroll();

		Gtk::CellRendererText m_PlaylistName;
		Glib::RefPtr<Gtk::UIManager> m_UIManager;
		MTPDevice& m_Device;

		bool m_bScrollOutOfPlaylist;
		sigc::connection expand_timeout;
		sigc::connection auto_scroll_timeout;
};

#endif // PLAYLIST_H
